function [NFiles,no_rec,PacCntr,lost_rec]=actis_file_stats(dir_path,session_ID)
% ACTIS_FILE_STATS reads data from Actis session 
% and generates statistics
%   [NFiles,NRec,PacCntr,lost_rec]=actis_file_stats(dir_path,session_ID)
% where
%   NFfiles is number of files
%   no_rec is number of records in each file
%   PacCntr is packet counter PacCntr(sensor,signal)
% 
% Note: Current version has fixed size result [10,12]
%       for up to 10 sensors and 12 signals.
%       All indeces start from 0 for Actis sensors and 1 for MATLAB.
%
% Signals and events:
% 0 - accX   4 - ECG2   8 - Step
% 1 - accY   5 - Aux1   9 - Rpeak
% 2 - accZ   6 - Aux2  10 - Force
% 3 - ECG1   7 - Aux3  11 - AEE
%
% See also: ACTIS_READ_AEE, ACTIS_READ_RR
% 
% Emil Jovanov
% UAH, June 2006
%

% packet counters PacCntr(sensor,signal)
PacCntr=zeros(10,12);
lost_rec=zeros(1,10);   % the number of lost records
first_rec=ones(1,10);   % logic denoting the first access to DSN value for each sensor
last_DSN=zeros(1,10);   % the number of lost records
no_rec=[];

i=0;
fname=strcat(dir_path,'SensorReport_',int2str(session_ID),'_',int2str(i),'.data');
while exist(fname)
    fid=fopen(fname);
    no_rec_session=0;
	% get all samples of type SignalID that belong to sensor SensorID
	while ~feof(fid)
        TimeStamp=fread(fid,1,'uint');
        NumValues=fread(fid,1,'ushort');
        DSN=fread(fid,1,'ushort');  % data sequence number (packet#)
        LastSampNum=fread(fid,1,'ushort');
        %
        b1=fread(fid,1,'uchar'); % SessionSignalID
        rSensorID=bitand(bitshift(b1,-4),15)+1; % SenID starts from 0
        rSignalID= bitand(b1,15)+1; % the lower four bits
		% Session
        b2=fread(fid,1,'uchar');b3=fread(fid,1,'uchar');b4=fread(fid,1,'uchar');
        Session=bitshift(b4,16)+bitshift(b3,8)+b2;
        tmp_data=fread(fid,10,'ushort'); % get data
        if (rSignalID <13) & (rSensorID <11)
            no_rec_session=no_rec_session+1;
            PacCntr(rSensorID,rSignalID)=PacCntr(rSensorID,rSignalID)+1;
        end
        if first_rec(rSensorID)
            first_rec(rSensorID)=0;
            last_DSN(rSensorID)=DSN;
        end
        if DSN > last_DSN(rSensorID)
            DSN_diff=DSN-last_DSN(rSensorID);
        else
            if DSN == last_DSN(rSensorID)
                DSN_diff=1;
            else
                DSN_diff=256-last_DSN(rSensorID)+DSN;
            end
        end
        if DSN_diff > 1
            lost_rec(rSensorID)=lost_rec(rSensorID)+DSN_diff-1;
        end
        last_DSN(rSensorID)=DSN;
	end % all records in a file
	fclose(fid);
    no_rec=[no_rec no_rec_session];
    i=i+1;
    % next session file
    fname=strcat(dir_path,'SensorReport_',int2str(session_ID),'_',int2str(i),'.data');
end % for all session files

NFiles=i;
