function [S,St,no_rec,lost_rec]=actis_read(dir_path,session_ID,SensorID,SignalID,Fs)
% ACTIS_READ reads one signal from Actis session. 
% The signal is specified with SensorID and SignalID.
% Sampling frequency is Fs. 
%
%   [S,St]=actis_read(dir_path,session_ID,SensorID,SignalID,Fs)
%
%   Signal is stored in S with signal time in St. 
%
% Note: All indeces start from 0 for Actis sensors and 1 for MATLAB.
%
% Signals and events:
% 0 - accX   4 - ECG2   8 - Step
% 1 - accY   5 - Aux1   9 - Rpeak
% 2 - accZ   6 - Aux2  10 - Force
% 3 - ECG1   7 - Aux3  11 - AEE
%
% See also: ACTIS_FILE_STATS, ACTIS_READ_RR, ACTIS_READ_AEE
% 
% Emil Jovanov
% UAH, July 2005
%

S=[];St=[];no_rec=[];lost_rec=[];

% Packet format
%Octets  Field         Description
% 4      Timestamp        32-bit global jiffy time
% 2      numValues        Number of values used in data field
% 2      Not used         Reserved for future timing parameters
% 2      LastSampNum
% 4      SessionSignalID  Unique identifier formed from concatenation of session number with signal type
% 20     data      Data dependent, for raw data this is 10 16-bit samples.
% 34 bytes                       

first_rec=1;
i=0;
fname=strcat(dir_path,'SensorReport_',int2str(session_ID),'_',int2str(i),'.data');
while exist(fname,'file')
    fid=fopen(fname);
    no_rec_session=0;
	% get all samples of type SignalID that belong to sensor SensorID
	while ~feof(fid)

    % skeep first three fields (currently not important)
    TimeStamp=fread(fid,1,'uint');
    NumValues=fread(fid,1,'ushort');
    NotUsed=fread(fid,1,'ushort');
    LastSampNum=fread(fid,1,'ushort');
    %
    b1=fread(fid,1,'uchar'); % SessionSignalID
    rSensorID=bitand(bitshift(b1,-4),15); % SenID starts from 0
    rSignalID= bitand(b1,15); % the lower four bits

    % skip SessionID
    b2=fread(fid,1,'uchar');b3=fread(fid,1,'uchar');b4=fread(fid,1,'uchar');
    Session=bitshift(b4,16)+bitshift(b3,8)+b2;
    
    tmp_data=fread(fid,10,'ushort'); % get data
    if (rSensorID == SensorID) & (rSignalID == SignalID)
        S=[S tmp_data'];
        St=[St ((LastSampNum-9):LastSampNum)./Fs];
    end
    end

	fclose(fid);
    no_rec=[no_rec no_rec_session];
    i=i+1;
    % next session file
    fname=strcat(dir_path,'SensorReport_',int2str(session_ID),'_',int2str(i),'.data');
end % for all session files

