function [RR,St,no_rec,lost_rec]=actis_read_RR(dir_path,SensorID,session_ID)
% ACTIS_READ_RR reads R-peak events from Actis session files
% at location dir_path with session_ID
%   [RR,St,no_rec,lost_rec]=actis_read_RR(dir_path,SensorID,session_ID)
%
%   The events are stored in vector RR with time [s] in St
% 
% Total number of records is stored in no_rec and 
% the number of lost records in lost-packets. 
% Note: All indeces start from 0 for Actis sensors and 1 for MATLAB.
%
% See also: ACTIS_FILE_STATS, ACTIS_READ, ACTIS_READ_AEE
% 
% Emil Jovanov
% UAH, June 2006
%

RR=[];St=[];no_rec=[];lost_rec=[];
% Packet format
%Octets  Field         Description
% 4      Timestamp        32-bit global jiffy time
% 2      numValues        Number of values used in data field
% 2      Not used         Reserved for future timing parameters
% 2      LastSampNum
% 4      SessionSignalID  Unique identifier formed from concatenation of session number with signal type
% 20     data      Data dependent, for raw data this is 10 16-bit samples.
% 34 bytes                       

first_rec=1;
i=0;
fname=strcat(dir_path,'SensorReport_',int2str(session_ID),'_',int2str(i),'.data');
while exist(fname,'file')
    fid=fopen(fname);
    no_rec_session=0;
	% get all samples of type SignalID that belong to sensor SensorID
	while ~feof(fid)
        TimeStamp=fread(fid,1,'uint');
        NumValues=fread(fid,1,'ushort');
        DSN=fread(fid,1,'ushort');
        LastSampNum=fread(fid,1,'ushort');
        %
        b1=fread(fid,1,'uchar'); % SessionSignalID
        rSensorID=bitand(bitshift(b1,-4),15); % SenID starts from 0
        rSignalID= bitand(b1,15); % the lower four bits
		% Session
        b2=fread(fid,1,'uchar');b3=fread(fid,1,'uchar');b4=fread(fid,1,'uchar');
        Session=bitshift(b4,16)+bitshift(b3,8)+b2;
        
        tmp_data=fread(fid,2,'ushort'); % get data
        RRintCandidate=fread(fid,1,'uint');
        tmp_data2=fread(fid,6,'ushort'); % get data
        if (rSensorID == SensorID) & (rSignalID == 9)   % SignalID = 9 (Rpeaks)
            if first_rec
                first_rec=0;
                last_DSN=DSN;
            end
            no_rec_session=no_rec_session+1;
            RR=[RR tmp_data(1)];
            St=[St TimeStamp/32768];
            no_rec_session=no_rec_session+1;
            if DSN > last_DSN
                DSN_diff=DSN-last_DSN;
            else
                if DSN == last_DSN
                    DSN_diff=1;
                else
                    DSN_diff=256-last_DSN+DSN;
                end
            end
            if DSN_diff > 1
                lost_rec=[lost_rec DSN_diff-1];
            else
                lost_rec=[lost_rec 0];
            end
            last_DSN=DSN;
        end
	end % all records in a file
	fclose(fid);
    no_rec=[no_rec no_rec_session];
    i=i+1;
    % next session file
    fname=strcat(dir_path,'SensorReport_',int2str(session_ID),'_',int2str(i),'.data');
end % for all session files
